@@ -17,7 +17,10 @@ import mysql.connector
 from mysql.connector import Error
 from pathlib import Path
 from wikibot.wikiuser import WikiUser
-    
+from mwdocker.logger import Logger
+from mwdocker.html_table import HtmlTables
+import pprint
+
 class DockerMap():
     '''
     helper class to convert lists of docker elements to maps for improved
@@ -34,6 +37,35 @@ class DockerMap():
             pass
         return containerMap
     
+class DockerContainer():
+    """
+    helper class for docker container info
+    """
+    
+    def __init__(self,name,kind,container):
+        """
+        constructor
+        """
+        self.name=name
+        self.kind=kind
+        self.container=container
+       
+    def check(self):
+        """
+        check the given docker container
+        
+        print check message and Return if container is running
+        
+        Args:
+            dc: the docker container
+        
+        Returns:
+            bool: True if the container is not None
+        """
+        ok=self.container.state.running
+        msg=f"mediawiki {self.kind} container {self.name}"
+        return Logger.check_and_log(msg, ok) 
+    
 class DockerApplication(object):
     '''
     MediaWiki Docker image
@@ -111,7 +143,20 @@ class DockerApplication(object):
             by downloading latest v2.x release from https://github.com/docker/compose-cli/releases for your architecture and move into ~/.docker/cli-plugins/docker-compose
 """
         return errMsg
-        
+    
+    def checkWiki(self,version_url:str):
+        """
+        check this wiki against the content of the given version_url
+        """
+        print(f"Checking {version_url} ...")
+        try:
+            html_tables=HtmlTables(version_url)
+            tables=html_tables.get_tables("h2")
+            p = pprint.PrettyPrinter(indent=2)
+            p.pprint(tables)
+        except Exception as ex:
+            Logger.check_and_log(str(ex), False)
+        pass
             
     def defaultContainerName(self):
         '''
@@ -128,9 +173,12 @@ class DockerApplication(object):
         return containerName
     
     def getContainers(self):
-        '''
+        """
         get my containers
-        '''
+        
+        Returns:
+            Tuple(
+        """
         self.dbContainer=None
         self.mwContainer=None
         containerMap=DockerMap.getContainerMap()
@@ -138,11 +186,10 @@ class DockerApplication(object):
             dbContainerName=self.getContainerName("db", separator)
             mwContainerName=self.getContainerName("mw", separator)
             if dbContainerName in containerMap:
-                self.dbContainerName=dbContainerName
-                self.dbContainer=containerMap[self.dbContainerName]
-            if mwContainerName in containerMap:
-                self.mwContainerName=mwContainerName
-                self.mwContainer=containerMap[self.mwContainerName]      
+                self.dbContainer=DockerContainer(dbContainerName,"database",containerMap[dbContainerName])
+            if mwContainerName in containerMap:               
+                self.mwContainer=DockerContainer(mwContainerName,"webserver",containerMap[mwContainerName])   
+        return self.mwContainer,self.dbContainer   
             
     def getJinjaEnv(self):
         '''
@@ -215,7 +262,7 @@ class DockerApplication(object):
         if self.mwContainer:
             if self.verbose:
                 print(f"Executing docker command {command}")
-            docker.execute(container=self.mwContainer,command=command)
+            docker.execute(container=self.mwContainer.container,command=command)
         else:
             mwContainerNameDash=self.getContainerName("mw", "-")
             mwContainerNameUnderscore=self.getContainerName("mw", "_")
@@ -403,8 +450,9 @@ class DockerApplication(object):
         if self.verbose:
             print(f"starting {self.name} {self.version} docker application ...")
         if forceRebuild:
-            for container in [self.dbContainer,self.mwContainer]:
-                if container is not None:
+            for docker_container in [self.dbContainer,self.mwContainer]:
+                if docker_container is not None:
+                    container=docker_container.container
                     if self.verbose:
                         print(f"stopping and removing container {container.name}")
                     container.stop()
